==> quanyi-center-api-0.0.73-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/code/RemoteCodeService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.code;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.code.CodeDto;
import cn.com.duiba.quanyi.center.api.param.code.CodeSearchParam;

import java.util.List;

/**
 * 渠道券码表
 *
 * @author lizhi
 * @date 2023/9/20 10:24
 */
@AdvancedFeignClient
public interface RemoteCodeService {

    /**
     * 根据券码查询
     *
     * @param couponCode 券码
     * @return 渠道券码
     */
    CodeDto selectByCode(String couponCode);

    /**
     * 券码失效
     *
     * @param couponCode 券码
     * @return
     */
    Boolean disable(String couponCode);

    /**
     * 批量插入渠道券码
     *
     * @param codeList 券码列表
     */
    void batchInsert(List<CodeDto> codeList);

    /**
     * 根据业务Id查询
     *
     * @param bizId       业务Id
     * @param codeBizType 业务类型，1-商品包制券
     * @return 券码列表
     * @see cn.com.duiba.quanyi.center.api.enums.code.CodeBizTypeEnum
     */
    List<CodeDto> queryByBizId(Long bizId, Integer codeBizType);

    /**
     * 根据业务Id查询
     *
     * @param bizId       业务Id
     * @param codeBizType 业务类型，1-商品包制券
     * @param codeStatus  状态
     * @return 券码列表
     * @see cn.com.duiba.quanyi.center.api.enums.code.CodeBizTypeEnum
     * @see cn.com.duiba.quanyi.center.api.enums.code.CodeStatusEnum
     */
    List<CodeDto> queryByBizIdAndStatus(Long bizId, Integer codeBizType, Integer codeStatus);

    /**
     * 绑定券码
     *
     * @param userId 用户ID
     * @param codeId 券码Id
     * @return 是否成功
     */
    boolean bind(Long userId, Long codeId);

    /**
     * 分页查询
     *
     * @param param param
     * @return 券码列表
     */
    List<CodeDto> selectPage(CodeSearchParam param);

    /**
     * 根据条件查询数量
     *
     * @param param param
     * @return 数量
     */
    Integer selectCount(CodeSearchParam param);

    /**
     * 根据短链查询订单号
     * @param linkList
     * @return
     */
    List<String> findGoodsOrderNoByLink(List<String> linkList);
}

==> quanyi-center-api-1.0.32-20240424.091139-3-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/code/RemoteCodeService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.code;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.code.CodeDto;
import cn.com.duiba.quanyi.center.api.param.code.CodeSearchParam;

import java.util.List;

/**
 * 渠道券码表
 *
 * @author lizhi
 * @date 2023/9/20 10:24
 */
@AdvancedFeignClient
public interface RemoteCodeService {

    /**
     * 根据券码查询
     *
     * @param couponCode 券码
     * @return 渠道券码
     */
    CodeDto selectByCode(String couponCode);

    /**
     * 根据券码查询
     *
     * @param couponCodes 券码
     * @return 渠道券码
     */
    List<CodeDto> selectByCodes(List<String> couponCodes);

    /**
     * 根据券链接查询
     *
     * @param link 券链接
     * @return 渠道券码
     */
    CodeDto selectByLink(String link);

    /**
     * 券码失效
     *
     * @param couponCode 券码
     * @return
     */
    Boolean disable(String couponCode);

    /**
     * 批量插入渠道券码
     *
     * @param codeList 券码列表
     */
    void batchInsert(List<CodeDto> codeList);

    /**
     * 根据业务Id查询
     *
     * @param bizId       业务Id
     * @param codeBizType 业务类型，1-商品包制券
     * @return 券码列表
     * @see cn.com.duiba.quanyi.center.api.enums.code.CodeBizTypeEnum
     */
    List<CodeDto> queryByBizId(Long bizId, Integer codeBizType);

    /**
     * 根据业务Id查询
     *
     * @param bizId       业务Id
     * @param codeBizType 业务类型，1-商品包制券
     * @param codeStatus  状态
     * @return 券码列表
     * @see cn.com.duiba.quanyi.center.api.enums.code.CodeBizTypeEnum
     * @see cn.com.duiba.quanyi.center.api.enums.code.CodeStatusEnum
     */
    List<CodeDto> queryByBizIdAndStatus(Long bizId, Integer codeBizType, Integer codeStatus);

    /**
     * 绑定券码
     *
     * @param userId 用户ID
     * @param codeId 券码Id
     * @return 是否成功
     */
    boolean bind(Long userId, Long codeId);

    /**
     * 分页查询
     *
     * @param param param
     * @return 券码列表
     */
    List<CodeDto> selectPage(CodeSearchParam param);

    /**
     * 根据条件查询数量
     *
     * @param param param
     * @return 数量
     */
    Integer selectCount(CodeSearchParam param);

    /**
     * 根据短链查询订单号
     * @param linkList
     * @return
     */
    List<String> findGoodsOrderNoByLink(List<String> linkList);
}
